# Music Grid Markdown
Write formatted music grids (chords and structures), with live preview.

The output are well formatted music grids, that you can view or print.
The input is a text file written in a special markdown syntax.

For more info wiew the project description on GitHub:
https://github.com/mpascucci/music_grid_markdown


Here is an example script:
```
# The Tune title
## version 1
Author: The Author // the composer's name
Copyright: The Big Big Band

- [INTRO]x2 Drums play 8 bars

- [A]x2 Play softly

4/4 [: Dm | Dm  A7 :]
| G | % | % | A7 Dm |

- [B] duble tempo

| Gm | D7 | Gm | D7 |
| Gm | Gm | Gm | D7 |

- [A]x2 -> [B]x2 -> [CODA]
```
